ivo_gt_theme: A nice GT theme

View source: R/ivo_table_gt.R

ivo_gt_themeR Documentation

A nice GT theme

Description

Applies a predefined theme to a GT table, including font, colors, and alignment.

Usage

ivo_gt_theme(table, color = "darkgreen", font_name = "Arial")

Arguments

table

A gt object.

color

A named color or a color HEX code, used for the lines in the table. Defaults to "darkgreen".

font_name

The name of the font to be used in the table. Defaults to "Arial".

Value

A styled gt table.

Author(s)

Stefan Furne


ivo.table documentation built on Nov. 25, 2025, 5:09 p.m.