| ivo_gt_theme | R Documentation |
Applies a predefined theme to a GT table, including font, colors, and alignment.
ivo_gt_theme(table, color = "darkgreen", font_name = "Arial")
table |
A |
color |
A named color or a color HEX code, used for the lines in the table. Defaults to "darkgreen". |
font_name |
The name of the font to be used in the table. Defaults to "Arial". |
A styled gt table.
Stefan Furne
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.