Learn R Programming

ivo.table (version 0.7.1)

ivo_gt_theme: A nice GT theme

Description

Applies a predefined theme to a GT table, including font, colors, and alignment.

Usage

ivo_gt_theme(table, color = "darkgreen", font_name = "Arial")

Value

A styled gt table.

Arguments

table

A gt object.

color

A named color or a color HEX code, used for the lines in the table. Defaults to "darkgreen".

font_name

The name of the font to be used in the table. Defaults to "Arial".

Author

Stefan Furne